<?php

namespace WFOTP\Admin;

class Settings
{
    public function __construct()
    {
        add_action('admin_menu', array($this, 'firebase_otp_settings_panel'));
        add_action('admin_menu', array($this, 'firebase_sync_data'));
        add_action('firebase_sync_user_data', array($this, 'sync_data'));
    }

    public function firebase_otp_settings_panel()
    {
        $page_title = esc_html__('Fire Mobile', 'wp-firebase-otp');
        $menu_title = esc_html__('Fire Mobile', 'wp-firebase-otp');
        $capability = 'manage_options';
        $menu_slug  = 'wp-firebase-otp-settings';
        $function   = array($this, 'firebase_otp_settings_func');
        $icon_url   = 'dashicons-media-code';
        $position   = 80;
        add_menu_page(
            $page_title,
            $menu_title,
            $capability,
            $menu_slug,
            $function,
            $icon_url,
            $position
        );
    }
    public function firebase_sync_data()
    {
        if (!class_exists('woocommerce')) {
            return;
        }
        $page_title = esc_html__('Sync WooCommerce customers data', 'wp-firebase-otp');
        $menu_title = esc_html__('Sync Data', 'wp-firebase-otp');
        $capability = 'manage_options';
        $menu_slug  = 'wp-firebase-sync-data';
        $function   = array($this, 'firebase_sync_data_func');
        $icon_url   = 'dashicons-media-code';
        $position   = 85;
        add_submenu_page(
            'wp-firebase-otp-settings',
            $page_title,
            $menu_title,
            $capability,
            $menu_slug,
            $function,
            $position
        );
    }

    public function firebase_otp_settings_func()
    {
        if (!current_user_can('manage_options')) {
            wp_die(
                esc_attr__('You do not have sufficient permissions to access this page.', 'wp-firebase-otp')
            );
        }
        include_once WFOTP_DIR . '/templates/admin/Settings.php';
    }

    public function firebase_sync_data_func()
    {
        if (!current_user_can('manage_options')) {
            wp_die(
                esc_attr__('You do not have sufficient permissions to access this page.', 'wp-firebase-otp')
            );
        }

        include_once WFOTP_DIR . '/templates/admin/SyncData.php';
    }
    public function add_single_action()
    {
        $wfotp_settings = get_option('wfotp_settings', true);
        $timestamp = strtotime($wfotp_settings['schedule_time']);
        $arg = array('my_custom_arg' => 'custom_value');
        $hook = 'firebase_sync_user_data';
        $group = '';
        $job_id = as_schedule_single_action($timestamp, $hook, $arg, $group);
        $message = esc_html__("Scheduler Added Successfully",);
        echo "<div class='rq-settings-notice'>" . $message . "</div>";
    }

    function sync_data()
    {
        //get all customer 
        if (!class_exists('woocommerce')) {
            return;
        }
        $args = array(
            'role'    => 'customer',
            'orderby' => 'user_nicename',
            'order'   => 'ASC'
        );
        $customers = get_users($args);

        foreach ($customers as $customer) {
            if (!empty($customer->billing_phone)) {
                update_user_meta($customer->ID, 'fm_user_phone', sanitize_text_field($customer->billing_phone), true);
            }
        }
    }
}
