<?php

namespace WFOTP\App;

class AsyncHandler
{
    /**
     * Action hook used by the AJAX class.
     *
     * @var string
     */
    const ACTION = 'wfotp_ajax';
    /**
     * Action argument used by the nonce validating the AJAX request.
     *
     * @var string
     */
    const NONCE = 'wfotp_ajax_nonce';
    /**
     * AsyncHandler constructor.
     */
    public function __construct()
    {
        add_action('wp_ajax_' . self::ACTION, array($this, 'handle_ajax'));
        add_action('wp_ajax_nopriv_' . self::ACTION, array($this, 'handle_ajax'));
    }
    public function handle_ajax()
    {
        check_ajax_referer(self::NONCE, 'nonce');
        $ajax_data = $_POST;
        unset($ajax_data['nonce']);
        unset($ajax_data['action']);
        switch ($ajax_data['action_type']) {
            case 'firebase_otp_login':
                $phoneNumber = !empty($ajax_data['phone_number']) ? $ajax_data['phone_number'] : false;
                $email = !empty($ajax_data['email']) ? $ajax_data['email'] : false;
                $uid = !empty($ajax_data['uid']) ? $ajax_data['uid'] : false;
                /** check if user is available */
                // Keeps only the numbers
                $loginByPhoneNumber = preg_replace('/[^0-9.]+/', '', $phoneNumber);

                $users = get_user_by('login', $loginByPhoneNumber);
                if (!empty($users)) {
                    /** user available in the db */
                    /** set user auth cookie */

                    wp_clear_auth_cookie();
                    wp_set_current_user($users->ID);
                    wp_set_auth_cookie($users->ID);
                } else {
                    // new creation step
                    $role = 'subscriber';
                    if (class_exists('woocommerce')) {
                        $role = 'customer';
                    }
                    // user is not available in the db
                    // insert user
                    $wfotp_settings = get_option('wfotp_settings', true);
                    $userdata = array(
                        'user_login' => $phoneNumber,
                        'user_email' => $email,
                        'user_pass'  =>  null, // When creating an user, `user_pass` is expected.
                        'role' => $role,
                    );

                    $user_id = wp_insert_user($userdata);
                    // On success.
                    if (!is_wp_error($user_id)) {
                        add_user_meta($user_id, '_firebase_uid', $uid);
                        add_user_meta($user_id, 'phone_number', sanitize_text_field($phoneNumber));
                        add_user_meta($user_id, 'fm_user_phone', sanitize_text_field($phoneNumber), true);

                        if (class_exists('woocommerce')) {
                            add_user_meta($user_id, 'billing_phone', sanitize_text_field($phoneNumber));
                        }
                        wp_clear_auth_cookie();
                        wp_set_current_user($user_id);
                        wp_set_auth_cookie($user_id);
                    }
                }
                //for previously existing user 
                $user = get_user_by('email', $email);
                $user_phone = get_user_meta($user->ID, 'fm_user_phone');



                if (!empty($user)) {
                    if (class_exists('woocommerce')) {
                        update_user_meta($user->ID, 'billing_phone', $phoneNumber);
                    }

                    if (empty($user_phone)) {

                        add_user_meta($user->ID, 'fm_user_phone', sanitize_text_field($phoneNumber), true);
                    }

                    wp_clear_auth_cookie();
                    wp_set_current_user($user->ID);
                    wp_set_auth_cookie($user->ID);
                }

                echo json_encode(
                    array(
                        'phone_number' => $phoneNumber,
                        'status' => 200,
                        'message' => esc_html__('Successful', 'wp-firebase-otp')
                    )
                );

                break;
        }
        wp_die();
    }
}
