<?php

namespace WFOTP\App;

defined('ABSPATH') || exit;
trait TemplateLoader
{
    /**
     * wfotp_get_template_part.
     *
     * @param string $template_name
     * @param array  $args
     * @param string $template_path
     * @param string $default_path
     */
    public function wfotp_get_template_part($template_name, $args = [], $template_path = '', $default_path = '')
    {
        if ($args && is_array($args)) {
            extract($args);
        }
        $located = $this->wfopt_locate_template($template_name, $template_path, $default_path);
        if (!file_exists($located)) {
            _doing_it_wrong(__FUNCTION__, sprintf('<code>%s</code> does not exist.', $located), '2.1');

            return;
        }
        $located = apply_filters('wfotp_get_template', $located, $template_name, $args, $template_path, $default_path);
        do_action('wfotp_before_template_part', $template_name, $template_path, $located, $args);
        include $located;
        do_action('wfotp_after_template_part', $template_name, $template_path, $located, $args);
    }

    /**
     * borobazar_locate_template.
     *
     * @param string $template_name
     * @param string $template_path
     * @param string $default_path
     */
    public function wfopt_locate_template($template_name, $template_path = '', $default_path = '')
    {
        if (!$template_path) {
            $template_path = WFOTP()->template_path();
        }

        if (!$default_path) {
            $default_path = WFOTP()->plugin_path() . '/templates/';
            
        }
    
        $template = locate_template(
            [
                trailingslashit($template_path) . $template_name,
                $template_name,
            ]
        );
        if (!$template) {
            $template = $default_path . $template_name;
        }
        
        return apply_filters('wfotp_locate_template', $template, $template_name, $template_path);
    }
}
