<?php
/*
* Plugin Name: Fire Mobile
* Plugin URI: https://redq.io
* Description: WordPress & WooCommerce firebase mobile OTP authentication.
* Version: 1.2.2
* Author: 20script
* Author URI: https://www.20script.ir
* Requires at least: 4.6
* Tested up to: 5.5
*
* Text Domain: wp-firebase-otp
* Domain Path: /languages/
*
* Copyright: © 2012-2020 RedQ,Inc.
* License: GNU General Public License v3.0
* License URI: http://www.gnu.org/licenses/gpl-3.0.html
*
*/

defined('ABSPATH') || exit;

/**
 * Class WFOTP
 */
class WFOTP
{

    /**
     * @var null
     */
    protected static $_instance = null;

    /**
     * @create instance on self
     */
    public static function instance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }


    public function __construct()
    {
        if (!defined('WFOTP_REQUIRED_PHP_VERSION')) {
            define('WFOTP_REQUIRED_PHP_VERSION', 5.6);
        }
        if (!defined('WFOTP_REQUIRED_WP_VERSION')) {
            define('WFOTP_REQUIRED_WP_VERSION', 4.5);
        }
        add_action('admin_init', array($this, 'check_version'));
        if (!self::compatible_version()) {
            return;
        }
        $this->wfotp_load_all_classes();
        $this->wfotp_app_bootstrap();
        add_action('plugins_loaded', array($this, 'wfotp_language_textdomain'), 1);
        add_filter('plugin_action_links_' . plugin_basename(__FILE__), [$this, 'action_links'], 1);
        add_filter('plugin_row_meta',  [$this, 'row_meta'], 10, 2);
    }

    /**
     * action_links
     *
     * @param array $links
     *
     * @return array
     */
    public function action_links($links)
    {
        $links[] = '<a href="' . admin_url('admin.php?page=wp-firebase-otp-settings') . '" target="_blank">' . __('Settings', 'wp-firebase-otp') . '</a>';
        $links[] = '<a href="https://www.youtube.com/watch?v=v57JAmZAI3A" target="_blank">' . __('Video', 'wp-firebase-otp') . '</a>';

        return $links;
    }

    /**
     * Row meta
     *
     * @param array $links
     * @param string $file
     * @return array
     */
    public function row_meta($links, $file)
    {
        if ('firemobile/WPFirebaseOTP.php' !== $file) {
            return $links;
        }

        $row_meta[] = '<a href="https://codecanyon.net/user/redqteam/portfolio?ref=redqteam" target="_blank">' . __('Portfolio', 'wp-firebase-otp') . '</a>';
        $row_meta[] = '<a href="https://redqsupport.ticksy.com/" target="_blank">' . __('Support', 'wp-firebase-otp') . '</a>';

        return array_merge($links, $row_meta);
    }

    public function wfotp_load_all_classes()
    {
        include_once __DIR__ . DIRECTORY_SEPARATOR . 'vendor' . DIRECTORY_SEPARATOR . 'autoload.php';
        require_once  __DIR__ . DIRECTORY_SEPARATOR . 'vendor' . DIRECTORY_SEPARATOR . '/cmb2/cmb2/init.php';
        // new WFOTP\App\LoadScripts();
        // new WFOTP\App\LoadShortcodes();
        //new WFOTP\App\AsyncHandler();
        new WFOTP\Admin\Settings();
        new WFOTP\Admin\FireMobileMetaBox();
        new WFOTP\App\Classes();
    }

    /**
     *  App Bootstrap
     *  Fire all class
     */
    public function wfotp_app_bootstrap()
    {
        /**
         * Define plugin constant
         */
        define('WFOTP_DIR', untrailingslashit(plugin_dir_path(__FILE__)));
        define('WFOTP_URL', untrailingslashit(plugins_url(basename(plugin_dir_path(__FILE__)), basename(__FILE__))));
        define('WFOTP_FILE', __FILE__);
        define('WFOTP_CSS', WFOTP_URL . '/assets/css/');
        define('WFOTP_LIB', WFOTP_URL . '/assets/lib/');
        define('WFOTP_IMG', WFOTP_URL . '/assets/img/');
        define('WFOTP_JS', WFOTP_URL . '/assets/js/');
        define('WFOTP_VEN', WFOTP_URL . '/assets/library/');
        define('WFOTP_FONTS', WFOTP_URL . '/assets/fonts/');
        define('WFOTP_SHORTCODES_PATH', plugin_dir_path(__FILE__) . 'Shortcodes/');
        define('WFOTP_TEMPLATE_PATH', WFOTP_DIR . '/templates/');
    }
    /**
     * ifIncludeTemplateFunctions.
     */
    // public function ifIncludeTemplateFunctions()
    // {
    //     include_once WFOTP_FILE . 'App/TemplateHooks.php';
    //     include_once WFOTP_FILE . 'App/TemplateFunctions.php';
    // }

    /**
     * Get the template path.
     *
     * @return string
     * @since 1.0.0
     */
    public function template_path()
    {
        return apply_filters('WFOTP_TEMPLATE_PATH', 'firemobile/');
    }

    /**
     * Get the plugin path.
     *
     * @return string
     * @since 1.0.0
     */
    public function plugin_path()
    {
        return untrailingslashit(plugin_dir_path(__FILE__));
    }

    /**
     * Get the plugin textdomain for multilingual.
     * @return null
     */
    public function wfotp_language_textdomain()
    {
        load_plugin_textdomain('wp-firebase-otp', false, dirname(plugin_basename(__FILE__)) . '/languages/');
    }


    static function compatible_version()
    {
        if (phpversion() < WFOTP_REQUIRED_PHP_VERSION || $GLOBALS['wp_version'] < WFOTP_REQUIRED_WP_VERSION) return false;
        return true;
    }

    // The backup sanity check, in case the plugin is activated in a weird way,
    // or the versions change after activation.
    public function check_version()
    {
        if (!self::compatible_version()) {
            if (is_plugin_active(plugin_basename(__FILE__))) {
                deactivate_plugins(plugin_basename(__FILE__));
                add_action('admin_notices', array($this, 'disabled_notice'));
                if (isset($_GET['activate'])) {
                    unset($_GET['activate']);
                }
            }
        }
    }



    public function disabled_notice()
    {
        if (phpversion() < WFOTP_REQUIRED_PHP_VERSION) { ?>
            <div class="notice notice-error is-dismissible">
                <p><?php esc_html_e('WP Firebase OTP! WP Firebase OTP requires PHP ' . WFOTP_REQUIRED_PHP_VERSION . ' or higher!', 'wp-firebase-otp'); ?></p>
            </div>
        <?php
        }
        if ($GLOBALS['wp_version'] < WFOTP_REQUIRED_WP_VERSION) { ?>
            <div class="notice notice-error is-dismissible">
                <p><?php esc_html_e('WP Firebase OTP! WP Firebase OTP requires Wordpress ' . WFOTP_REQUIRED_WP_VERSION . ' or higher!', 'wp-firebase-otp'); ?></p>
            </div>
<?php
        }
    }
}

/**
 * @return null|WFOTP
 */
function WFOTP()
{

    return WFOTP::instance();
}


$GLOBALS['wfotp'] = WFOTP();
